{% extends "eztables/base.html" %}
{% load js %}

{% block server-side %}active{% endblock %}

{% block container %}

<h2>Server-side processing</h2>

<div class="row subnav">
    <div class="navbar">
        <div class="navbar-inner">
            <div class="container">
                <ul class="nav">
                    <li class="{% block server-side-base %}{% endblock %}">
                        <a href="{% url server-side %}">Base processing</a>
                    </li>
                    <li class="{% block server-side-search %}{% endblock %}">
                        <a href="{% url server-side-search %}">Search modes</a>
                    </li>
                    <li class="{% block server-side-objects %}{% endblock %}">
                        <a href="{% url server-side-objects %}">Using objects</a>
                    </li>
                    <li class="{% block server-side-custom %}{% endblock %}">
                        <a href="{% url server-side-custom %}">Custom variables</a>
                    </li>
                </ul>
            </div>
        </div>
    </div>
</div>

{% block server-side-container %}{% endblock %}

{% endblock %}

{% block extra-script %}
    {% js "js/eztables.server.js" %}
    {% block server-side-extra-script %}{% endblock %}
{% endblock %}
