{% extends "eztables/server-side.html" %}
{% load js %}

{% block server-side-custom %}active{% endblock %}

{% block server-side-container %}

<div class="row">
    <span class="label label-warning">TODO</span>
</div>

{% endblock %}

{% block server-side-extra-script %}
    {% js "js/eztables.server.custom.js" %}
{% endblock %}
