/*
 * jQuery DataTables Bootstrap style
 *
 * Based on: http://www.datatables.net/media/blog/bootstrap_2/
 *
 */

.dataTables_wrapper {
    position: relative;
    clear: both;
    zoom: 1; /* Feeling sorry for IE */
    font: 80%/1.45em "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
    color: #333;
}

.dataTables_length {
    width: 40%;
}

.filterbar {
    float: right;
    margin-right: 10px;
}


.filterbar .pagination {
    margin: 0;
}

.filterbar .pagination a {
    line-height: 18px;
}

.dataTables_filter {
    float: right;
    text-align: right;
}

.dataTables_info {
    width: 60%;
    float: left;
}

.dataTables_paginate {
    float: right;
    text-align: right;
    margin: 5px 0 5px;
}

/* Pagination nested */
.paginate_disabled_previous, .paginate_enabled_previous,
.paginate_disabled_next, .paginate_enabled_next {
    height: 19px;
    float: left;
    cursor: pointer;
    *cursor: hand;
    color: #111 !important;
}
.paginate_disabled_previous:hover, .paginate_enabled_previous:hover,
.paginate_disabled_next:hover, .paginate_enabled_next:hover {
    text-decoration: none !important;
}
.paginate_disabled_previous:active, .paginate_enabled_previous:active,
.paginate_disabled_next:active, .paginate_enabled_next:active {
    outline: none;
}

.paginate_disabled_previous,
.paginate_disabled_next {
    color: #666 !important;
}
.paginate_disabled_previous, .paginate_enabled_previous {
    padding-left: 23px;
}
.paginate_disabled_next, .paginate_enabled_next {
    padding-right: 23px;
    margin-left: 10px;
}

.paginate_disabled_previous {
    background: url('../images/back_disabled.png') no-repeat top left;
}

.paginate_enabled_previous {
    background: url('../images/back_enabled.png') no-repeat top left;
}
.paginate_enabled_previous:hover {
    background: url('../images/back_enabled_hover.png') no-repeat top left;
}

.paginate_disabled_next {
    background: url('../images/forward_disabled.png') no-repeat top right;
}

.paginate_enabled_next {
    background: url('../images/forward_enabled.png') no-repeat top right;
}
.paginate_enabled_next:hover {
    background: url('../images/forward_enabled_hover.png') no-repeat top right;
}

div.dataTables_length label {
    float: left;
    text-align: left;
}

div.dataTables_length select {
    width: 75px;
}

div.dataTables_filter label {
    float: right;
}

div.dataTables_info {
    padding-top: 8px;
}

table.table.dataTable {
    margin: 0 auto;
    width: 100%;
}

table.table {
    clear: both;
    /*margin-bottom: 6px !important;*/
}

table.table thead .sorting,
table.table thead .sorting_asc,
table.table thead .sorting_desc,
table.table thead .sorting_asc_disabled,
table.table thead .sorting_desc_disabled {
    cursor: pointer;
    *cursor: hand;
}

table.table thead .sorting { background: url('../images/sort_both.png') no-repeat center right; }
table.table thead .sorting_asc { background: url('../images/sort_asc.png') no-repeat center right; }
table.table thead .sorting_desc { background: url('../images/sort_desc.png') no-repeat center right; }

table.table thead .sorting_asc_disabled { background: url('../images/sort_asc_disabled.png') no-repeat center right; }
table.table thead .sorting_desc_disabled { background: url('../images/sort_desc_disabled.png') no-repeat center right; }

table.dataTable th:active {
    outline: none;
}
